#!/bin/bash

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c etc/config.mk"
	echo "   -s sync pdf files"
	echo "   -r remove remote pdf files"
	echo "   -l last book"
	echo "   -a generate all book env before run"
	echo "   -p commit and push to amusewiki"
	echo "   -j delete job log"
	echo "   -i do not clone git before run"
	echo "   -q do not remove current git files"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:jsrlapiq" opt; do
    case "${opt}" in
        c) . "${OPTARG}" && cflag=true ;;     # etc/config.mk
        j) jflag=true ;;
	s) sflag=true ;;
	r) rflag=true ;;
	l) lflag=true ;;
	a) aflag=true ;;
	p) pflag=true ;;
        i) iflag=true ;;
	q) qflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

# clean jobs and exit
if [[ "${jflag}" == "true" ]]; then ssh amusewiki "sqlite3 ${AMUSEWIKI_REMOTE_DB} 'DELETE FROM job;'"; exit 0; fi

# generate book ENV
if [[ "${lflag}" == "true" ]]; then
	. "${AMUSEWIKI_BOOK_ENV}" &>/dev/null
	if [[ ! "${book[first]}" == "${book[last]}" ]]; then
		"${GENERATOR_PATH}/lib/generate.sh" last-book-env
	fi
else
	. "${AMUSEWIKI_BOOK_ENV}" &>/dev/null
	if [[ "${book[first]}" == "${book[last]}" ]]; then
		"${GENERATOR_PATH}/lib/generate.sh" book-env
	fi
fi

if [[ "${aflag}" == "true" ]]; then
	"${GENERATOR_PATH}/lib/generate.sh" book-env
fi

# include book ENV
. "${AMUSEWIKI_BOOK_ENV}" &>/dev/null

# delete old files
if [[ ! "${qflag}" ]]; then
	rm -rf "${AMUSEWIKI_GIT_PATH}"
fi

# clone remote repo
if [[ ! "${iflag}" ]]; then
	git clone ${AMUSEWIKI_GIT_SSH} "${AMUSEWIKI_GIT_PATH}"
fi

# write all data
for i in $(seq "${book[first]}" "${book[last]}"); do
	trap "echo Exited!; exit;" SIGINT SIGTERM

	ID=${book[$i,uuid]}
	FC=${ID:0:1}
	LC=${ID: -1}
	OUTDIR="${AMUSEWIKI_GIT_PATH}/${FC}/${FC}${LC}"
	OUTPUT="${OUTDIR}/${ID}.muse"
	SOURCE="${IPFS_PDF_DIR}/${book[$i,url]}.pdf"
	LAST=; if [[ "${book[$i,lastmodified]}" ]]; then LAST="Son güncelleme: ${book[$i,lastmodified]}"; fi

	mkdir -p "${OUTDIR}"

	# add white space
	st=; if [[ "${book[$i,subtitle]}" ]]; then st=" "; fi
        ss=; if [[ "${book[$i,SORTtopics]}" ]]; then ss=" "; fi
	sp=; if [[ "${book[$i,publisher]}" ]]; then sp=" "; fi
	sl=; if [[ "${book[$i,lastmodified]}" ]]; then sl=" "; fi
        sn=; if [[ "${book[$i,notes]}" ]]; then sn=" "; fi
	al=; if [[ "${book[$i,library]}" ]]; then al=" "; fi
	ai=; if [[ "${book[$i,library_issue]}" ]]; then ai=" "; fi

echo "#ATTACH ${ID}.pdf
#title ${book[$i,title]}
#subtitle${st}${book[$i,subtitle]}
#author ${book[$i,author]}
#SORTauthors ${book[$i,author]}
#SORTtopics${ss}${book[$i,SORTtopics]}
#source [[${SOURCE}][${IPFS_PDF_DIR_PREVIEW}]]
#lang ${book[$i,lang]}
#pubdate ${book[$i,pubdate]}
#notes${sn}${book[$i,notes]}
#amwpublisher${sp}${book[$i,publisher]}
#amwuuid ${book[$i,uuid]}
#amwmodified${sl}${book[$i,lastmodified]}
#amwdirectory ${book[$i,directory]}
#amwlang ${book[$i,lang]}
#amwlibrary${al}${book[$i,library]}
#amwlibraryissue${ai}${book[$i,library_issue]}
" | sed "s/\&#39;/'/g" > "${OUTPUT}"

	# attach pdf
	if [[ "${sflag}" == "true" ]]; then
		echo "${PDF_PATH}/${book[$i,url]}.pdf -> ${AMUSEWIKI_REMOTE}:${AMUSEWIKI_REPO_DIR}/uploads/${ID}.pdf"
		rsync --update -raz "${PDF_PATH}/${book[$i,url]}.pdf" ${AMUSEWIKI_REMOTE}:${AMUSEWIKI_REPO_DIR}/uploads/${ID}.pdf
	fi

	# remove remote pdf file
	if [[ "${rflag}" == "true" ]]; then
		echo "remove: ${AMUSEWIKI_REMOTE}:${AMUSEWIKI_REPO_DIR}/uploads/${ID}.pdf"
		ssh ${AMUSEWIKI_REMOTE} rm -f ${AMUSEWIKI_REPO_DIR}/uploads/${ID}.pdf
	fi
done

# push to amusewiki
if [[ "${pflag}" = "true" ]]; then
	git -C "${AMUSEWIKI_GIT_PATH}" add .
	if [[ "${book[first]}" == "${book[last]}" ]]; then
		git -C "${AMUSEWIKI_GIT_PATH}" commit -m "add last book: ${DATE}"
	else
		git -C "${AMUSEWIKI_GIT_PATH}" commit -m "sync: ${DATE}"
	fi
	git -C "${AMUSEWIKI_GIT_PATH}" push
fi
