#!/bin/bash

# print usage info
usage() {
	echo "Usage: ${BASH_SOURCE[0]} -d DB -c etc/config.mk"
	echo "    -m commit"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":d:c:m" opt; do
    case "${opt}" in
        d) sqlite_file="${OPTARG}" ; if [[ ! $(head -c 13 "${sqlite_file}") = "SQLite format" ]]; then echo "Input file is not SQLite. aborting"; exit 1; else _sqlite_exist=true; fi ;;
	c) . "${OPTARG}" ; cflag="true";;
	m) mflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

# remove empty records from all column
sqlite3 -echo "${sqlite_file}" < <(
	while IFS= read -r column; do
		echo "UPDATE books SET ${column} = NULL WHERE ${column} = '';"
	done < <(sqlite3 "${sqlite_file}" "SELECT name FROM PRAGMA_TABLE_INFO('books');")
	echo "VACUUM;"
)

# commit change
if [[ "${mflag}" == "true" ]]; then
	if [[ ! "${cflag}" ]]; then
		echo "-c option must be specified to commit"
		exit 1
	fi
	if ! git -C "${GENERATOR_PATH}" diff --exit-code "${sqlite_file}" &>/dev/null; then
	        git -C "${GENERATOR_PATH}" add "${sqlite_file}"
        	git -C "${GENERATOR_PATH}" commit "${sqlite_file}" -m "clean empty records"
	fi
fi
