#!/bin/bash

##################################
# Author by letter
# Arguments:
#   SQLite db
#   config file
# Outputs:
#   Writes variables to stdout
##################################

# print usage info
usage() {
    echo "Usage: ${BASH_SOURCE[0]} -d DB -c etc/config.mk"
    exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":d:c:" opt; do
    case "${opt}" in
        d) sqlite_file="${OPTARG}" ;;
        c) . ${OPTARG} && cflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

readarray -t book_author < <(sqlite3 "${sqlite_file}" "SELECT author FROM books ${SQLITE_QUERY}" | sed "s/'/\&#39;/g")
readarray -t book_title < <(sqlite3 "${sqlite_file}" "SELECT title FROM books ${SQLITE_QUERY}"| sed "s/'/\&#39;/g")
readarray -t book_url < <(sqlite3 "${sqlite_file}" "SELECT ${BOOK_SLUG_RULE} FROM books ${SQLITE_QUERY}" | url_slug)
readarray -t book_id < <(seq "0" "$((${#book_title[@]} - 1))")
readarray -t book_uuid < <(sqlite3 "${sqlite_file}" "SELECT uuid FROM books ${SQLITE_QUERY}")
readarray -t author_list < <(sqlite3 "${sqlite_file}" "SELECT author FROM books ${SQLITE_QUERY}" | sed 's/, /\n/g' | awk '!seen[$0]++')
readarray -t char < <(printf "%s\n" "${author_list[@]}" | cut -c 1 | LC_ALL=tr_TR.UTF-8 tr '[:lower:]' '[:upper:]' | sort -u)
readarray -t char_accent < <(printf "%s\n" "${char[@]}" | sed 's/Ü/UE/g; s/Ç/CH/g; s/İ/IE/g; s/Ğ/GH/g; s/Ş/SH/g; s/Ú/UU/g; s/É/EE/g; s/Ö/OE/g')

echo "declare -A char"
echo "char[count]=\"${#char[@]}\""
echo "char[first]=\"0\""
echo "char[last]=\"$((${#char[@]} - 1))\""

for i in "${!char[@]}"; do

    readarray -t "_author_by_char" < <(printf "%s\n" "${author_list[@]}" | grep -i "^${char[$i]}")
    # find fastest way!
    readarray -t "_author_by_char_url" < <(printf "%s\n" "${author_list[@]}" | grep -i "^${char[$i]}" | url_slug)

    echo "char[$i,title]=\"${char[$i]}\""
    echo "char[$i,accent]=\"${char_accent[$i]}\""
    echo "char[$i,author,count]=\"${#_author_by_char_url[@]}\""
    echo "char[$i,author,first]=\"0\""
    echo "char[$i,author,last]=\"$((${#_author_by_char_url[@]} - 1))\""

    for a in "${!_author_by_char[@]}"; do

        readarray -t _id_by_book < <(
            paste <(printf "%s\n" "${book_id[@]}") <(printf "%s\n" "${book_author[@]}") |
                grep "${_author_by_char[$a]}" |
                awk '{print $1}'
        )

        echo "char[$i,author,$a,title]=\"${_author_by_char[$a]}\""
        echo "char[$i,author,$a,url]=\"${_author_by_char_url[$a]}\""
        echo "char[$i,author,$a,book,count]=\"${#_id_by_book[@]}\""
        echo "char[$i,author,$a,book,first]=\"0\""
        echo "char[$i,author,$a,book,last]=\"$((${#_id_by_book[@]} - 1))\""

        for id in "${!_id_by_book[@]}"; do
            echo "char[$i,author,$a,book,$id,title]=\"${book_title[${_id_by_book[$id]}]}\""
            echo "char[$i,author,$a,book,$id,url]=\"${book_url[${_id_by_book[$id]}]}\""
                            echo "char[$i,author,$a,book,$id,uuid]=\"${book_uuid[${_id_by_book[$id]}]}\""
        done

    done

done
