#!/bin/bash

#########################################
# Convert index table to unix variables.
# Arguments:
#   SQLite db
#   config file
# Outputs:
#   Writes variables to stdout
#########################################

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -d DB -c etc/config.mk"
        exit 1
    } ; if [[ "$#" -lt 1 ]]; then usage; fi

    # parse options
    while getopts ":d:c:" opt; do
            case "${opt}" in
                    d) sqlite_file="${OPTARG}" ;;
                    c) . ${OPTARG} && cflag=true ;;
                    :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
                    *) usage ;;
            esac
    done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

# declare for multidimensional index array
echo -e "declare -A index\n"



########################
# SPECIFIC AUTHOR INDEX
########################

# get author count from index
num_rows=$(sqlite3 "${sqlite_file}" "SELECT COUNT(author) FROM site_index")

# get author book count from books
author_book_count_list=$(sqlite3 "${sqlite_file}" "SELECT author FROM books ${SQLITE_QUERY}" | sed 's/, /\n/g' | sort | uniq -c)


# read db into bash array
# notice: author names are not sorted
readarray -t author_index < <(sqlite3 "${sqlite_file}" "SELECT author FROM site_index")
readarray -t author_index_url < <(sqlite3 "${sqlite_file}" "SELECT author FROM site_index" | url_slug )

# print author count
echo "index[author,count]=\"${num_rows}\"
index[author,first]=\"0\"
index[author,last]=\"$((num_rows - 1))\""

# print author_index array to stdout
for ((i = 0; i < num_rows; i++)); do
echo "index[author,$i,title]=\"${author_index[$i]}\"
index[author,$i,url]=\"${author_index_url[$i]}\"
index[author,$i,count]=\"$(grep "${author_index[$i]}" <<<"${author_book_count_list}" | awk '{print $1}')\""
done



#############
# BOOK INDEX
#############

# get author count from index
num_rows=$(sqlite3 "${sqlite_file}" "SELECT COUNT(title) FROM books ${SQLITE_QUERY}")

# read db into bash array
# TODO: prevent name conflict
readarray -t book_index < <(sqlite3 "${sqlite_file}" "SELECT title FROM books ${SQLITE_QUERY}" | sed "s/'/\&#39;/g")
readarray -t book_index_subtitle < <(sqlite3 "${sqlite_file}" "SELECT subtitle FROM books ${SQLITE_QUERY}" | sed "s/'/\&#39;/g")
readarray -t book_index_pubdate < <(sqlite3 "${sqlite_file}" "SELECT pubdate FROM books ${SQLITE_QUERY}")
readarray -t book_index_url < <(sqlite3 "${sqlite_file}" "SELECT ${BOOK_SLUG_RULE} FROM books ${SQLITE_QUERY}" | url_slug)
readarray -t author_index < <(sqlite3 "${sqlite_file}" "SELECT author FROM books ${SQLITE_QUERY}" | sed "s/'/\&#39;/g")
readarray -t author_index_url < <(sqlite3 "${sqlite_file}" "SELECT author FROM books ${SQLITE_QUERY}" | url_slug )
readarray -t directory < <(sqlite3 "${sqlite_file}" "SELECT directory FROM books ${SQLITE_QUERY}")

# print book count
echo "
index[book,count]=\"${num_rows}\"
index[book,first]=\"0\"
index[book,last]=\"$((num_rows - 1))\""

# print book array to stdout
for ((i = 0; i < num_rows; i++)); do
echo "index[book,$i,title]=\"${book_index[$i]}\"
index[book,$i,subtitle]=\"${book_index_subtitle[$i]}\"
index[book,$i,pubdate]=\"${book_index_pubdate[$i]}\"
index[book,$i,url]=\"${book_index_url[$i]}\"
index[book,$i,directory]=\"${directory[$i]//unlisted,/}\"
index[book,$i,author,title]=\"${author_index[$i]}\"
index[book,$i,author,url]=\"${author_index_url[$i]}\""
done | sed 's/=\"null\"/=\"\"/g'



###########################
# SITEMAP ENTITY INDEX
###########################

entity_first_gp="0"
entity_last_gp="$(($(echo "${GENERATED_PAGES}" | wc -l) - 1))"
    entity_first_sp="${entity_last_gp}"
    entity_last_sp="$(($(echo "${STATIC_PAGES}" | wc -l) + ${entity_last_gp}))"

echo ""
echo "index[sitemap_entity,first]=\"${entity_first_gp}\""
echo "index[sitemap_entity,last]=\"${entity_last_sp}\""

while IFS= read -r gp_line; do
    i="$((entity_first_gp++))"
    echo "index[sitemap_entity,$i,url]=\"${gp_line}\""
    echo "index[sitemap_entity,$i,pubdate]=\"${DATE}\""
done < <(echo "${GENERATED_PAGES}")

while IFS= read -r sp_line; do
    i="$((entity_first_gp++))"
    sp_sl="$(echo "${sp_line}" | awk '{print $1}')"
    sp_rl="$(echo "${sp_line}" | awk '{print $2}')"
    echo "index[sitemap_entity,$i,url]=\"${sp_sl}\""
    echo "index[sitemap_entity,$i,pubdate]=\"$(${DATE_CMD} -r "${GENERATOR_PATH}/${sp_rl}")\""
done < <(echo "${STATIC_PAGES}")
