#!/bin/bash

# print usage info
usage() {
	echo "Usage: ${BASH_SOURCE[0]} -d DB -c etc/config.mk [ -q ]"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:d:q" opt; do
    case "${opt}" in
        d) sqlite_file="${OPTARG}" ; if [[ ! $(head -c 13 "${sqlite_file}") = "SQLite format" ]]; then echo "Input file is not SQLite. aborting"; exit 1; else _sqlite_exist=true; fi ;;
        c) . "${OPTARG}" ; cflag=true ;;
	q) qflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi
if [[ ! "${_sqlite_exist}" == "true" ]]; then echo "sqlite file must be specified"; exit 1; fi

rm -f "${sqlite_file}.pre"
mv "${sqlite_file}" "${sqlite_file}.post"
git -C "${GENERATOR_PATH}" restore "${sqlite_file}"
mv "${sqlite_file}" "${sqlite_file}.pre"
mv "${sqlite_file}.post" "${sqlite_file}"
cmp -s "${sqlite_file}" "${sqlite_file}.pre" && { echo "No difference between ${sqlite_file} and ${sqlite_file}.pre" ; rm -f "${sqlite_file}.pre"; exit 0 ; }

if [[ "${qflag}" == "true" ]]; then
	sqldiff "${sqlite_file}.pre" "${sqlite_file}"
	exit 0
fi

echo -e "\n\033[0;31mOutput SQL text that would transform ${sqlite_file} into ${sqlite_file}.pre:\033[0m"
sqldiff "${sqlite_file}" "${sqlite_file}.pre"

echo -e "\n\033[0;31mOutput SQL text that would transform ${sqlite_file}.pre into ${sqlite_file}:\033[0m"
sqldiff "${sqlite_file}.pre" "${sqlite_file}"
