#!/bin/bash
# required function url_slug()

# print usage info
usage() {
	echo "Usage: ${BASH_SOURCE[0]} -d DB -c etc/config.mk -a action
  -a:
      show	show the different status
      delete	delete the files that are not in the database
      download	download the files that are not in the directory
      move	fix wrong file names
      nginx	generate nginx configuration for renamed entries"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:d:a:" opt; do
    case "${opt}" in
	d) sqlite_file="${OPTARG}" ; if [[ ! $(head -c 13 "${sqlite_file}") = "SQLite format" ]]; then echo "Input file is not SQLite. aborting"; exit 1; else _sqlite_exist=true; fi ;;
        c) . "${OPTARG}" ; CONFIG="${OPTARG}" ; cflag=true ;;
	a) ACTION="${OPTARG}" ; aflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi
if [[ ! "${_sqlite_exist}" == "true" ]]; then echo "sqlite file must be specified"; exit 1; fi

mkdir -p "${TEMP}"

sqlite3 "${sqlite_file}" "SELECT ${BOOK_SLUG_RULE} FROM books" | url_slug | sort -u | sed 's/$/.pdf/' > "${TEMP}/sqlite-file-index.txt"
ls -1 "${PDF_PATH}" | sort -u > "${TEMP}/ls-file-index.txt"
notindir="$(grep -Fxvf "${TEMP}/ls-file-index.txt" "${TEMP}/sqlite-file-index.txt")"
notindb="$(grep -Fxvf "${TEMP}/sqlite-file-index.txt" "${TEMP}/ls-file-index.txt")"
rm -f "${TEMP}/ls-file-index.txt" "${TEMP}/sqlite-file-index.txt"


if [[ "${aflag}" == "true" ]]; then
	case "${ACTION}" in
		show)
			echo -e "\033[0;31mfiles in the database that are not in the ${PDF_DIR}/ directory:\033[0m"
			if [[ -z "${notindir}" ]]; then
				echo "Not found"
			else
				echo "${notindir}"
			fi

			echo -e "\033[0;31mfiles in the ${PDF_DIR}/ directory that are not in the database:\033[0m"
			if [[ -z "${notindb}" ]]; then
				echo "Not found"
			else
				echo "${notindb}"
			fi
		;;
		download)
			while IFS= read -r file; do
                                if [[ -z "${notindir}" ]]; then
                                        echo "No files will be downloaded"
                                        exit 1
                                fi
				echo "wget --no-check-certificate -O \"${PDF_PATH}/${file}\" \"${SYNC_URL}/${PDF_DIR}/${file}\""
				wget --no-check-certificate -O "${PDF_PATH}/${file}" "${SYNC_URL}/${PDF_DIR}/${file}"
			done <<< "${notindir}"
		;;
		delete)
			while IFS= read -r file; do
				if [[ -z "${notindb}" ]]; then
					echo "No files will be deleted"
					exit 1
				fi
				echo "rm \"${PDF_PATH}/$file\""
				rm "${PDF_PATH}/$file"
			done <<< "${notindb}"
		;;
		move)
			while IFS= read -r line; do
				notindb_file="$(echo "${line}" | awk '{print $1}')"
				notindir_file="$(echo "${line}" | awk '{print $2}')"
				echo "mv \"${PDF_PATH}/${notindb_file}\" \"${PDF_PATH}/${notindir_file}\""
			done < <(paste <(printf "%s\n" "${notindb}") <(printf "%s\n" "${notindir}"))
		;;
		nginx)
			printf "%s\n" "${notindb}" | sed 's/.pdf//g' > "${TEMP}/.notindb"
			printf "%s\n" "${notindir}" | sed 's/.pdf//g' > "${TEMP}/.notindir"
			"${GENERATOR_PATH}/lib/url2nginx-rule.sh" -1 "${TEMP}/.notindb" -2 "${TEMP}/.notindir" -t file -n book -c "${CONFIG}"
		;;
		*)
			echo "Unexpected option: ${ACTION}"
			usage
			exit 1
		;;
	esac
fi
