#!/bin/bash
# Function collection for generator.

# ROMANIZE
#romanize() { unidecode; }	# install: pip install Unidecode
romanize() { iconv -f ${ICONV_FROM_CODE} -t ascii//TRANSLIT; }

############################################
# Convert gived title to sluged url
# Arguments:
#   stdin text
# Outputs:
#   Writes slugs to stdout
#############################################
url_slug() {
	romanize | \
	cut -c 1-250 | \
	sed -r s/\'//g | \
	sed -r 's/\(//g' | \
	sed -r 's/\)//g' | \
	sed -r s/[~\^]+//g | \
	sed -r s/[^a-zA-Z0-9]+/-/g | \
	sed -r s/^-+\|-+$//g | \
	tr A-Z a-z
}

#####################################################
# If base64 string empty doesn't call base64 command
# Benefit:
#   fastest converting
# Arguments:
#   stdin base64
# Outputs:
#   Writes text to stdout
#####################################################
decode_base64() {
	if [[ ! -z "${1}" ]]; then
		echo "${1}" | base64 -d
	else
		return 1
	fi
}

##############################
# Give error prompt
# Arguments:
#  error message
# Outputs:
#  redirects to stderr
##############################
error() {
	echo "$*" >&2
}


##############################
# Give unused port
# Arguments:
#  none
# Outputs:
#  Writes text to stdout
##############################
get_port() {
	python3 -c 'import socket; s=socket.socket(); s.bind(("", 0)); print(s.getsockname()[1]); s.close()'
}

###############################
# Give random uuid without dash
# Arguments:
#  none
# Outputs:
#  Writes data to stdout
###############################
get_uuid() {
	UUID=$(uuidgen)
	echo ${UUID//-/}
}
