#!/bin/sh

BREW_LIST="	python git jq sqlite make gcc imagemagick@6 sqldiff openssl ghostscript"
APT_LIST="	python3-pip git jq sqlite3 sqlite3-tools make gcc graphicsmagick-imagemagick-compat openssl uuid-runtime ghostscript"
PACMAN_LIST="	python-pip git jq sqlite make gcc python3 ImageMagick sqldiff openssl ghostscript"
YUM_LIST="	python3-pip git jq sqlite make gcc imagemagick openssl ghostscript"

UNAME=$(uname -s)

are_you_sure() {
	printf "Are you sure? (Y/n) "
	read -r REPLY

	if [ "$(echo "$REPLY" | tr '[:upper:]' '[:lower:]')" != "y" ]; then
		printf "\n"
		exit 1
	fi
}

if [ "$UNAME" = "Darwin" ]; then
	HAS_BREW=$(command -v brew > /dev/null 2>&1 && echo 1 || echo 0)
	if [ "$HAS_BREW" -eq 1 ]; then
		echo "The following packages will be installed:"
		echo ""
		echo "${BREW_LIST}"
		echo ""
		are_you_sure
		brew update
		brew install ${BREW_LIST} || exit 1
	fi
elif [ "$UNAME" = "Linux" ]; then
	HAS_APT=$(command -v apt-get > /dev/null >&1 && echo 1 || echo 0)
	HAS_PACMAN=$(command -v pacman > /dev/null >&1 && echo 1 || echo 0)
	HAS_YUM=$(command -v yum > /dev/null >&1 && echo 1 || echo 0)

	if [ "$(id -u)" != "0" ]; then
		echo "Please run this script as root"
		exit 1
	fi

	if [ "$HAS_APT" -eq 1 ]; then
		echo "The following packages will be installed:"
		echo ""
		echo "${APT_LIST}"
		echo ""
		are_you_sure
		apt-get update
		apt-get install -y ${APT_LIST} || exit 1
	elif [ "$HAS_PACMAN" -eq 1 ]; then
		echo "The following packages will be installed:"
		echo ""
		echo "${PACMAN_LIST}"
		echo ""
		are_you_sure
		pacman -Syy
		pacman -S --needed ${PACMAN_LIST} || exit 1
	elif [ "$HAS_YUM" -eq 1 ]; then
		echo "The following packages will be installed:"
		echo ""
		echo "${YUM_LIST}"
		echo ""
		are_you_sure
		yum makecache
		yum install -y ${PACMAN_LIST} || exit 1
	else
		echo "Unknown Linux distribution"
		echo 'Please run the "make check" command and deal with the relevant requirements yourself.'
		exit 1
	fi
else
	echo "Unknown platform"
	echo 'Please run the "make check" command and deal with the relevant requirements yourself.'
	exit 1
fi
