#!/bin/bash
# This script installs scrtipt-server with user defined variables

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c CONFIG"
	echo " -i install"
	echo " -w write configuration"
	echo " -s serve"
	echo " -t enable|disable (for theme)"
	echo " -d print systemd configuration"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi


# parse options
while getopts ":c:t:wisd" opt; do
    case "${opt}" in
        c) . "${OPTARG}" ; cflag=true ;;     # etc/config.mk
	t) theme_option="${OPTARG}" ; tflag=true ;;
	w) wflag="true" ;;
	i) iflag="true" ;;
	s) sflag="true" ;;
	d) dflag="true" ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

if [[ "${wflag}" == "true" ]]; then

mkdir -p "${SCRIPT_SERVER_PATH}/conf/runners"
mkdir -p "${GENERATOR_PATH}/var/extra/put_pdf"

cat > "${SCRIPT_SERVER_PATH}/conf/conf.json" <<EOT
{
  "max_request_size": "${SCRIPT_SERVER_MAX_REQUEST_SIZE}",
  "port": "${SCRIPT_SERVER_PORT}",
  "title": "${SCRIPT_SERVER_TITLE}",
  "address": "${SCRIPT_SERVER_BIND}",
  "access": {
     "allowed_users": [ ${SCRIPT_SERVER_ALLOWED_USERS} ],
     "admin_users": [ ${SCRIPT_SERVER_ADMIN_USERS} ],
     "groups": {
        "all": [ ${SCRIPT_SERVER_GROUPS_ALL} ]
     },
     "trusted_ips": [ ${SCRIPT_SERVER_TRUSTED_IPS} ]
  },
  "ssl": {
     "key_path": "${GENERATOR_PATH}/var/extra/ssl/script-server.key",
     "cert_path": "${GENERATOR_PATH}/var/extra/ssl/script-server.crt"
  }
}
EOT


cat > "${SCRIPT_SERVER_PATH}/conf/runners/Upload_PDF.json" <<EOF
{
  "name": "Upload PDF",
  "script_path": "${GENERATOR_PATH}/sbin/add",
  "working_directory": "${GENERATOR_PATH}",
  "output_format": "terminal",
  "parameters": [
    {
      "name": "Title",
      "required": true,
      "param": "-t",
      "same_arg_param": false,
      "type": "text"
    },
    {
      "name": "Subtitle",
      "required": false,
      "param": "-z"
    },
    {
      "name": "Author",
      "required": true,
      "param": "-a",
      "type": "text"
    },
    {
      "name": "Topics",
      "required": false,
      "param": "-k",
      "type": "text"
    },
    {
      "name": "Publisher",
      "required": true,
      "param": "-x",
      "type": "text"
    },
    {
      "name": "Language",
      "required": true,
      "param": "-l",
      "type": "text",
      "default": "tr"
    },
    {
      "name": "Date",
      "required": false,
      "param": "-p",
      "same_arg_param": false,
      "type": "text",
      "no_value": false,
      "secure": false
    },
    {
      "name": "Directory",
      "required": true,
      "param": "-s",
      "default": "Kitap",
      "type": "multiselect",
      "values": [
        "unlisted",
        "Anar\u015fist K\u00fct\u00fcphane",
        "Kitap",
        "Dergi",
        "Yeni"
      ],
      "multiselect_argument_type": "single_argument",
      "separator": ", "
    },
    {
      "name": "Notes",
      "required": false,
      "param": "-y",
      "type": "text"
    },
    {
      "name": "ISBN",
      "required": false,
      "param": "-i",
      "type": "text"
    },
    {
      "name": "Library",
      "required": false,
      "param": "-b",
      "type": "text"
    },
    {
      "name": "Library Issue",
      "required": false,
      "param": "-n",
      "type": "text"
    },
    {
      "name": "Special Slug",
      "required": false,
      "param": "-q",
      "type": "text"
    },
    {
      "name": "Upload PDF",
      "required": false,
      "param": "-f",
      "type": "file_upload"
    },
    {
      "name": "Upload PDF from server",
      "param": "-f",
      "type": "server_file",
      "file_dir": "${GENERATOR_PATH}/var/extra/put_pdf"
    },
    {
      "name": "Database",
      "required": true,
      "param": "-d",
      "no_value": false,
      "default": "var/db/books.db",
      "secure": false
    },
    {
      "name": "Config",
      "required": true,
      "param": "-c",
      "no_value": false,
      "default": "etc/config.mk"
    },
    {
      "name": "Verbose",
      "default": true,
      "param": "-v",
      "no_value": true
    },
    {
      "name": "Generate Page",
      "default": true,
      "param": "-g",
      "no_value": true
    },
    {
      "name": "Generate Unlisted Site",
      "default": false,
      "param": "-u",
      "no_value": true
    },
    {
      "name": "Commit",
      "default": true,
      "param": "-m",
      "no_value": true
    },
    {
      "name": "Add book also to amusewiki",
      "default": true,
      "param": "-w",
      "no_value": true
    }
  ]
}
EOF


cat > "${SCRIPT_SERVER_PATH}/conf/runners/Remove_entry.json" << EOF
{
  "name": "Remove entry",
  "script_path": "${GENERATOR_PATH}/sbin/remove",
  "working_directory": "${GENERATOR_PATH}",
  "parameters": [
    {
      "name": "Database",
      "required": true,
      "param": "-d",
      "default": "var/db/books.db"
    },
    {
      "name": "Config",
      "required": true,
      "param": "-c",
      "no_value": false,
      "default": "etc/config.mk"
    },
    {
      "name": "Title",
      "param": "-t"
    },
    {
      "name": "Subtitle",
      "param": "-s"
    },
    {
      "name": "Author",
      "param": "-a"
    },
    {
      "name": "ID",
      "param": "-i"
    },
    {
      "name": "Remove last book",
      "param": "-e",
      "no_value": true
    },
    {
      "name": "List entries",
      "param": "-l",
      "no_value": true
    },
    {
      "name": "Restore DB",
      "param": "-r",
      "no_value": true
    },
    {
      "name": "Generate Pages",
      "param": "-g",
      "no_value": true
    },
    {
      "name": "Generate Unlisted Site",
      "default": false,
      "param": "-u",
      "no_value": true
    },
    {
      "name": "Commit",
      "param": "-m",
      "no_value": true
    },
    {
      "name": "Remove book also from amusewiki",
      "default": true,
      "param": "-w",
      "no_value": true
    },
    {
      "name": "Do not vacuum",
      "default": true,
      "param": "-q",
      "no_value": true
    },
    {
      "name": "Verbose",
      "param": "-v",
      "no_value": true
    }
  ]
}
EOF

cat > "${SCRIPT_SERVER_PATH}/conf/runners/Replace.json" <<EOF
{
  "name": "Replace PDF",
  "script_path": "${GENERATOR_PATH}/sbin/replace",
  "working_directory": "${GENERATOR_PATH}",
  "parameters": [
    {
      "name": "Database",
      "required": true,
      "param": "-d",
      "default": "var/db/books.db"
    },
    {
      "name": "Config",
      "required": true,
      "param": "-c",
      "default": "etc/config.mk"
    },
    {
      "name": "New PDF",
      "param": "-f",
      "type": "file_upload"
    },
    {
      "name": "New PDF from server",
      "param": "-f",
      "type": "server_file",
      "file_dir": "${GENERATOR_PATH}/var/extra/put_pdf"
    },
    {
      "name": "ID",
      "param": "-i"
    },
    {
      "name": "Title",
      "param": "-t"
    },
    {
      "name": "Author",
      "param": "-a"
    },
    {
      "name": "Subtitle",
      "param": "-s"
    },
    {
      "name": "Verbose",
      "param": "-v",
      "no_value": true
    },
    {
      "name": "Generate Page",
      "param": "-g",
      "no_value": true
    },
    {
      "name": "Generate Unlisted Site",
      "default": false,
      "param": "-u",
      "no_value": true
    },
    {
      "name": "Commit",
      "param": "-m",
      "no_value": true
    }
  ]
}
EOF

cat > "${SCRIPT_SERVER_PATH}/conf/runners/Search_entry.json" <<EOF
{
  "name": "Search entry",
  "script_path": "${GENERATOR_PATH}/sbin/search",
  "working_directory": "${GENERATOR_PATH}",
  "requires_terminal": false,
  "output_format": "html_iframe",
  "parameters": [
    {
      "name": "Database",
      "required": true,
      "param": "-d",
      "default": "var/db/books.db"
    },
    {
      "name": "Title",
      "param": "-t"
    },
    {
      "name": "Subtitle",
      "param": "-s"
    },
    {
      "name": "Author",
      "param": "-a"
    },
    {
      "name": "ID",
      "param": "-i"
    },
    {
      "name": "Output type",
      "param": "-p",
      "type": "multiselect",
      "default": "html",
      "values": [
        "html",
        "csv",
        "json",
        "table",
        "line"
      ],
      "multiselect_argument_type": "repeat_param_value"
    }
  ]
}
EOF

cat > "${SCRIPT_SERVER_PATH}/conf/runners/SQLite_Editor.json" <<EOF
{
  "name": " SQLite Editor",
  "script_path": "make -s install-sqlite-editor run-sqlite-editor",
  "working_directory": "${GENERATOR_PATH}",
  "output_format": "terminal",
  "parameters": []
}
EOF
fi

if [[ "${iflag}" == "true" ]]; then
	mkdir -p "${SCRIPT_SERVER_PATH}"
	wget -O "${SCRIPT_SERVER_PATH}/source.zip" "${SCRIPT_SERVER_SOURCE}"
	unzip -o "${SCRIPT_SERVER_PATH}/source.zip" -d "${SCRIPT_SERVER_PATH}"
	if [[ -x "$(command -v pip3)" ]]; then
		pip3 install -r "${SCRIPT_SERVER_PATH}/requirements.txt"
	else
		pip install -r "${SCRIPT_SERVER_PATH}/requirements.txt"
	fi
fi

if [[ "${tflag}" == "true" ]]; then
	case "${theme_option}" in
		enable)
			mkdir -p "${SCRIPT_SERVER_PATH}/conf/theme"
			wget -O "${SCRIPT_SERVER_PATH}/conf/theme/theme.css" "${SCRIPT_SERVER_THEME_CSS}"
			wget -O "${SCRIPT_SERVER_PATH}/conf/theme/$(basename "${SCRIPT_SERVER_THEME_HEADER_IMAGE}")" "${SCRIPT_SERVER_THEME_HEADER_IMAGE}"
			wget -O "${SCRIPT_SERVER_PATH}/conf/theme/$(basename "${SCRIPT_SERVER_THEME_LOGIN_IMAGE}")" "${SCRIPT_SERVER_THEME_LOGIN_IMAGE}"
		;;
		disable)
			rm -rf "${SCRIPT_SERVER_PATH}/conf/theme"
		;;
		*)
			echo "Unexpected option: ${theme_option}"
			exit 1
		;;
	esac
fi

if [[ "${sflag}" == "true" ]]; then
	"${SCRIPT_SERVER_PATH}/launcher.py"
fi

if [[ "${dflag}" == "true" ]]; then
cat <<EOF
[Unit]
Description=Script Server
After=network.target

[Service]
User=${USER}
ExecStart=make -C "${GENERATOR_PATH}" run-script-server
ExecReload=ps a | grep "launcher.py" | head -1 | awk '{print $1}' | xargs kill -9
Restart=on-failure
RestartSec=2

[Install]
WantedBy=multi-user.target
EOF
fi
