#!/bin/bash
# This script installs sqlite-viewer

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c CONFIG"
	echo " -i install"
	echo " -s serve"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:is" opt; do
    case "${opt}" in
        c) . "${OPTARG}" ; cflag=true ;;     # etc/config.mk
	i) iflag="true" ;;
	s) sflag="true" ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

if [[ "${iflag}" == "true" ]]; then
	rm -rf "${SQLITE_VIEWER_PATH}"
	wget -O "${SQLITE_VIEWER_PATH}-source.zip" "${SQLITE_VIEWER_SOURCE}"
	unzip -o "${SQLITE_VIEWER_PATH}-source.zip" -d "${SQLITE_VIEWER_PATH}-temp"
	mv "${SQLITE_VIEWER_PATH}-temp/sqlite-viewer-gh-pages/" "${SQLITE_VIEWER_PATH}/"
	rmdir "${SQLITE_VIEWER_PATH}-temp"
	rm "${SQLITE_VIEWER_PATH}-source.zip"
	#regex
	sed -i '/<footer>/,/<\/footer>/d' "${SQLITE_VIEWER_PATH}/index.html"
	sed -i 's/<h3>SQLite Viewer<\/h3>/<a href="?url=books.db"><h3>SQLite Viewer<\/h3><\/a>/g' "${SQLITE_VIEWER_PATH}/index.html"
fi

if [[ "${sflag}" == "true" ]]; then
	TEMP_SERVER_PORT="$(get_port)"
	echo -e "\nVISIT: http://${TEMP_SERVER_BIND}:${TEMP_SERVER_PORT}/?url=books.db\n"

	if [[ ! -f "${SQLITE_VIEWER_PATH}/books.db" ]]; then
		unlink "${SQLITE_VIEWER_PATH}/books.db" 2>/dev/null
		ln -s "${GENERATOR_PATH}/var/db/books.db" "${SQLITE_VIEWER_PATH}/"
	fi

	if [[ -x "$(command -v python3.10)" ]]; then
        	python3.10 -m http.server --directory "${SQLITE_VIEWER_PATH}" --bind ${TEMP_SERVER_BIND} ${TEMP_SERVER_PORT}
	else
        	cd "${SQLITE_VIEWER_PATH}"
        	python3 -m http.server --bind ${TEMP_SERVER_BIND} ${TEMP_SERVER_PORT}
	fi
fi
