#!/usr/bin/env python3

import argparse
from bs4 import BeautifulSoup

def remove_div(html_content):
    soup = BeautifulSoup(html_content, 'html.parser')
    div_to_remove = soup.find('div', {'id': 'preamble-container', 'class': 'well'})
    if div_to_remove:
        div_to_remove.decompose()

    return str(soup)

def replace_div(html_content, replacement_html):
    soup = BeautifulSoup(html_content, 'html.parser')
    div_to_replace = soup.find('div', {'class': 'amw-attachments-container col-xs-offset-4 col-xs-4 center'})
    if div_to_replace:
        replacement_div = BeautifulSoup(replacement_html, 'html.parser')
        div_to_replace.replace_with(replacement_div)

    return str(soup)

def main():
    parser = argparse.ArgumentParser(description="HTML Div Manipulation")
    parser.add_argument("--html-input", required=True, help="Input HTML file")
    parser.add_argument("--text-input", required=True, help="Input HTML code for replacement")
    parser.add_argument("--html-output", required=True, help="Output HTML file")
    args = parser.parse_args()

    # Read HTML content from input file
    with open(args.html_input, 'r') as html_input_file:
        html_content = html_input_file.read()

    # Read replacement HTML code from text input
    with open(args.text_input, 'r') as text_input_file:
        replacement_html = text_input_file.read()

    # Remove and replace div elements using Beautiful Soup
    html_content = remove_div(html_content)
    html_content = replace_div(html_content, replacement_html)

    # Write modified HTML content to output file
    with open(args.html_output, 'w') as html_output_file:
        html_output_file.write(html_content)

if __name__ == "__main__":
    main()
