#!/bin/bash

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c etc/config.mk"
	echo "   -a generate all book env before run"
	echo "   -f force regenerate files"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:af" opt; do
    case "${opt}" in
        c) . "${OPTARG}" && cflag=true ;;     # etc/config.mk
        a) aflag=true ;;
        f) fflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

# generate book ENV
if [[ "${aflag}" == "true" ]]; then
	"${GENERATOR_PATH}/lib/generate.sh" book-env
fi

# include book ENV
. "${AMUSEWIKI_BOOK_ENV}" &>/dev/null

# generate pages
mkdir -p "${TEMP}/l2u/output"
cat > "${UNLISTED_LIBRARY_NGX}" <<EOT
subs_filter_types text/html text/css text/xml;
EOT
for i in $(seq "${book[first]}" "${book[last]}"); do
#	if [[ "${book[$i,directory]}" == *"unlisted"* ]]; then
#		# name the input
#		HTML_INPUT="${TEMP}/l2u/${book[$i,uuid]}.html"
#		HTML_OUTPUT="${TEMP}/l2u/output/${book[$i,uuid]}.html"
#		TEXT_INPUT="${TEMP}/l2u/${book[$i,uuid]}.txt"
#
#		# download html files
#		if [[ "${fflag}" == "true" ]]; then
#			curl -s "${AMUSEWIKI_URL}/library/${book[$i,uuid]}" > "${HTML_INPUT}"
#			echo "curl -s ${AMUSEWIKI_URL}/library/${book[$i,uuid]} > ${HTML_INPUT}"
#		else
#			if [[ ! -f "${HTML_INPUT}" ]]; then
#				curl "${AMUSEWIKI_URL}/library/${book[$i,uuid]}" > "${HTML_INPUT}"
#				echo "curl -s ${AMUSEWIKI_URL}/library/${book[$i,uuid]} > ${HTML_INPUT}"
#			fi
#		fi
#
#		# generate txt files
#		# copied from src/build/book/451-index.html
#cat > "${TEXT_INPUT}" <<EOT
#      <div class='download-container'>
#         <div class='download-box'>
#            <a href='https://annas-archive.org/search?q=${book[$i,isbn]}'>annas-archive.org</a>
#         </div>
#         <div class='download-box'>
#            <a href='https://libgen.li/index.php?req=${book[$i,isbn]}'>libgen.li</a>
#         </div>
#      </div>
#      <p>Erişmeye çalıştığınız içerik bölgenizde mevcut değildir, indirmek için lütfen yukarıdaki harici kaynaklardan birini seçin.</p>
#EOT
#
#		# write output files
#		if [[ "${fflag}" == "true" ]]; then
#			"${GENERATOR_PATH}/lib/library2unlisted.py" --html-input ${HTML_INPUT} --text-input ${TEXT_INPUT} --html-output ${HTML_OUTPUT}
#			echo -e "${GENERATOR_PATH}/lib/library2unlisted.py --html-input ${HTML_INPUT} --text-input ${TEXT_INPUT} --html-output ${HTML_OUTPUT}\n"
#		else
#			if [[ ! -f "${HTML_OUTPUT}" ]]; then
#				"${GENERATOR_PATH}/lib/library2unlisted.py" --html-input ${HTML_INPUT} --text-input ${TEXT_INPUT} --html-output ${HTML_OUTPUT}
#				echo -e "${GENERATOR_PATH}/lib/library2unlisted.py --html-input ${HTML_INPUT} --text-input ${TEXT_INPUT} --html-output ${HTML_OUTPUT}\n"
#			fi
#		fi
#
#		# write nginx configuration
#		# copied from lib/unlisted.sh
#
#		unset UUID
#		UUID="${book[$i,uuid]}"
#cat >> "${UNLISTED_LIBRARY_NGX}" << EOT
#location = /library/${UUID}/ { if (\$allowed_country = no) { rewrite ^ /library/${UUID} redirect; } }
#location = /uploads/anarchocopy/${UUID}.pdf { if (\$allowed_country = no) { rewrite ^ /library/${UUID} redirect; } }
#location /library/${UUID} { if (\$allowed_country = no) { return 451; error_page 451 /451/${UUID}.html; } }
#EOT
#	fi

	# write nginx configuration
	# copied from lib/unlisted.sh
	unset UUID
	UUID="${book[$i,uuid]}"
	cat >> "${UNLISTED_LIBRARY_NGX}" << EOT
subs_filter "${AMUSEWIKI_URL}/uploads/anarchocopy/${UUID}.pdf" "${IPFS_PDF_DIR}/${book[$i,url]}.pdf";
location = /uploads/anarchocopy/${UUID}.pdf { rewrite ^ ${IPFS_PDF_DIR}/${book[$i,url]}.pdf redirect; }
EOT

done
