#!/bin/bash

# print usage info
usage() {
	echo "Usage: ${BASH_SOURCE[0]} -c CONFIG [ -l ]"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:l" opt; do
    case "${opt}" in
        c) . "${OPTARG}" ;;     # etc/config.mk
	l) lflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

targets="$(make -rpn -C "${GENERATOR_PATH}" | sed -n -e '/^$/ { n ; /^[^ .#][^ ]*:/ { s/:.*$// ; p ; } ; }' | grep -v "\-\-" | sort -u)"

if [[ "${lflag}" == "true" ]]; then
	if [[ -z "${GENERATOR_PATH}" ]]; then
		echo "'GENERATOR_PATH' variable is required. please give config file"
		usage
		exit 1
	fi

	while IFS= read -r target; do
		targethelp="$(cat "${GENERATOR_PATH}/etc/generator.d/makehelp/${target}" 2>/dev/null )"
		echo "+${target} +${targethelp}"
	done <<< "${targets}" | column -t -s '+'

	exit 0
fi

mkdir -p "${SCRIPT_SERVER_PATH}/conf/runners"

cat > "${SCRIPT_SERVER_PATH}/conf/runners/Makefile.json" <<EOT
{
  "name": "Makefile",
  "script_path": "make",
  "working_directory": "${GENERATOR_PATH}",
  "parameters": [
EOT


line_count="$(echo "${targets}" | wc -l)"
current_line="0"
while IFS= read -r target; do
current_line="$(($current_line + 1))"
cat >> "${SCRIPT_SERVER_PATH}/conf/runners/Makefile.json" <<EOT
    {
      "name": "${target}",
      "param": "${target}",
      "no_value": true
    }$(if [[ ! "${current_line}" == "${line_count}" ]]; then echo ","; fi )
EOT

done <<< "${targets}"


cat >> "${SCRIPT_SERVER_PATH}/conf/runners/Makefile.json" <<EOT
  ]
}
EOT
