#!/bin/bash

# print usage info
usage() {
	echo "Usage: ${BASH_SOURCE[0]} -c etc/config.mk [ -n column | -a ]"
	echo "   -l last page"
	echo "   -i do not clone git before run"
	exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:n:ali" opt; do
	case "${opt}" in
		c) . "${OPTARG}" ; cflag=true ;;     # etc/config.mk
		n) column_arg="${OPTARG}" ; nflag=true ;;
		a) aflag="true" ;;
		l) lflag="true" ;;
		i) gflag="true" ;;
		:) echo "Error: -${OPTARG} requires an argument." ; usage ;;
		*) usage ;;
	esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

# generate book ENV
if [[ "${lflag}" == "true" ]]; then
	. "${AMUSEWIKI_BOOK_ENV}" &>/dev/null
	if [[ ! "${book[first]}" == "${book[last]}" ]]; then
		"${GENERATOR_PATH}/lib/generate.sh" last-book-env
	fi
else
	. "${AMUSEWIKI_BOOK_ENV}" &>/dev/null
	if [[ "${book[first]}" == "${book[last]}" ]]; then
		"${GENERATOR_PATH}/lib/generate.sh" book-env
	fi
fi

# include book ENV
. "${AMUSEWIKI_BOOK_ENV}" &>/dev/null

# delete old files and clone git
if [[ ! "${iflag}" == "true" ]]; then
	rm -rf "${AMUSEWIKI_GIT_PATH}"
	git clone ${AMUSEWIKI_GIT_SSH} "${AMUSEWIKI_GIT_PATH}"
fi

# set column name
if [[ "${nflag}" == "true" ]]; then
	columns="${column_arg}"
	if_column="true"
fi

if [[ ${aflag} == "true" ]]; then
	columns=$(
		sqlite3 "${AMUSEWIKI_DB}" "SELECT name FROM PRAGMA_TABLE_INFO('books');"
	)
	if_column="true"
fi

if [[ ! "${if_column}" ]]; then
	echo "no columns are assigned"
	exit 1
fi

# rewrite all data to database
sqlite3 -echo "${AMUSEWIKI_DB}" < <(
	while IFS= read -r column; do
		for i in $(seq "${book[first]}" "${book[last]}"); do
			ID=${book[$i,uuid]}; FC=${ID:0:1}; LC=${ID: -1}
			MUSE="${AMUSEWIKI_GIT_PATH}/${FC}/${FC}${LC}/${ID}.muse"
			column_var="$(sed -n "s/#${column} //p" "${MUSE}")"
			if [[ ! -z "${column_var}" ]]; then
				if [[ ! "${column_var}" == "${book[$i,$column]}" ]]; then
					echo "UPDATE books SET ${column}='${column_var//\'/\'\'}' WHERE uuid='${ID}';"
				fi
			fi
		done | sed 's/\"/\\\"/g'
	done <<< "${columns}"
)
