#!/bin/bash

# print usage info
usage() {
	echo "Usage: ${BASH_SOURCE[0]} -d DB -t table -a DATA -q QUERY -r REPLACE"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":d:t:a:q:r:" opt; do
    case "${opt}" in
	d) sqlite_file="${OPTARG}" ; if [[ ! $(head -c 13 "${sqlite_file}") = "SQLite format" ]]; then echo "Input file is not SQLite. aborting"; exit 1; else _sqlite_exist=true; fi ;;
	t) TABLE="${OPTARG}" ; tflag=true ;;
	a) DATA="${OPTARG}" ; aflag=true ;;
	q) QUERY="${OPTARG}" ; qflag=true ;;
	r) REPLACE="${OPTARG}" ; rflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

if [[ ! "${_sqlite_exist}" == "true" ]]; then echo "sqlite file must be specified"; exit 1; fi
if [[ ! "${tflag}" == "true" ]]; then echo "sqlite table must be specified"; exit 1; fi
if [[ ! "${aflag}" == "true" ]]; then echo "sqlite data must be specified"; exit 1; fi
if [[ ! "${qflag}" == "true" ]]; then echo "query must be specified"; exit 1; fi
if [[ ! "${rflag}" == "true" ]]; then echo "replace must be specified"; exit 1; fi


sqlite3 "${sqlite_file}" <<EOT
UPDATE ${TABLE} SET ${DATA} = REPLACE(${DATA},'${REPLACE}','TEMP_CHAR');
UPDATE ${TABLE} SET ${DATA} = REPLACE(${DATA},'${QUERY}','TEMP_CHAR');
UPDATE ${TABLE} SET ${DATA} = REPLACE(${DATA},'TEMP_CHAR','${REPLACE}');
EOT
