#!/bin/bash

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c etc/config.mk -t target"
	echo "	-u safely unlink and delete created files"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:t:u" opt; do
    case "${opt}" in
        c) . "${OPTARG}" ; cflag=true ;; # etc/config.mk
        t) target="$(realpath "${OPTARG}")" ; tflag=true ;;
        u) uflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi
if [[ ! "${tflag}" ]]; then echo "-t option must be specified"; exit 1; fi
if [[ ! -d "${target}" ]]; then echo "${target} is not a directory."; exit 1; fi
if [[ -f "${GENERATOR_PATH}/var/extra/_production_exist" ]]; then BUILD_PATH="${BUILD_PATH}-prod"; fi
if [[ ! "${BUILD_PATH}" ]]; then echo "BUILD_PATH must be gived"; exit 1; fi

# remove trailing slash
BUILD_PATH="$(realpath "${BUILD_PATH}")"

# SET domain
DOMAIN="$(basename "${URL}")"

# unlink
if [[ "${uflag}" == "true" ]]; then
	unlink "${target}/https:"
	unlink "${target}/http:/${DOMAIN}"
	unlink "${target}/http:/www.${DOMAIN}"
	rm -rf "${target}/http:"
	exit 0
fi

# main
mkdir "${target}/http:"
ln -s "${BUILD_PATH}" "${target}/http:/${DOMAIN}"
ln -s "${BUILD_PATH}" "${target}/http:/www.${DOMAIN}"
ln -s "${target}/http:" "${target}/https:"
