#!/bin/bash

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c etc/config.mk"
	echo "   -l last book"
	echo "   -a generate all book env before run"
	echo "   -n restart nginx"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:lan" opt; do
    case "${opt}" in
        c) . "${OPTARG}" && cflag=true ;;     # etc/config.mk
	l) lflag=true ;;
	a) aflag=true ;;
	n) nflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

# generate book ENV
if [[ "${lflag}" == "true" ]]; then
	. "${SQLITE_EDITOR_BOOK_ENV}" &>/dev/null
	if [[ ! "${book[first]}" == "${book[last]}" ]]; then
		"${GENERATOR_PATH}/lib/generate.sh" last-book-env
	fi
else
	. "${SQLITE_EDITOR_BOOK_ENV}" &>/dev/null
	if [[ "${book[first]}" == "${book[last]}" ]]; then
		"${GENERATOR_PATH}/lib/generate.sh" book-env
	fi
fi

if [[ "${aflag}" == "true" ]]; then
	"${GENERATOR_PATH}/lib/generate.sh" book-env
fi

# include book ENV
. "${SQLITE_EDITOR_BOOK_ENV}" &>/dev/null


# delete nginx configuration if not a single book
if [[ ! "${book[first]}" == "${book[last]}" ]]; then
	rm -f "${SQLITE_EDITOR_NGX_PATH}"
fi

# write all data
for i in $(seq "${book[first]}" "${book[last]}"); do
	ID="${book[$i,url]}"
	ROW="$((${book[$i,row_id]}+1))"
	URI="/edit.php?&table=books&action=row_editordelete&pk=[${ROW}]&type=edit"

	# remove if nginx configuration found
	if [[ "${book[first]}" == "${book[last]}" ]]; then
		sed -i "/${ID}/d" "${SQLITE_EDITOR_NGX_PATH}" &>/dev/null
	fi

	# write nginx configuration
	echo "location = /${BOOK_DIR}/${ID}/edit { return 301 ${URI}; }" >> "${SQLITE_EDITOR_NGX_PATH}"
done

if [[ "${nflag}" == "true" ]]; then
	nginx_restart
else
	echo "# restart nginx:"
	echo "nginx -t && systemctl restart nginx.service"
fi
