#!/bin/bash
# This script archives entire pdf directory and sends it to the https://transfer.sh

# set time format
TIMEFORMAT="%R"

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c etc/config.mk -n nginx_conf"
	echo "  -w working directory"
	echo "  -t enable tor"
	echo "  -f archive file"
	echo "  -d delete old file"
	echo "  -n write nginx configuration"
	echo "  -s transfer.sh|bashupload.com|0x0.st|oshi.at|anonfiles.com|filechan.org|letsupload.cc"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:w:tf:dn:s:" opt; do
	case "${opt}" in
		c) . "${OPTARG}" ; cflag=true ;;     # etc/config.mk
		w) workdir="$(realpath "${OPTARG}")" ; wflag="true" ;;
		t) tflag="true" ;;
		f) archive="${OPTARG}" ; fflag="true" ;;
		d) dflag="true" ;;
		n) nginx_config="$(realpath "${OPTARG}")" ; nflag="true" ;;
		s) service="${OPTARG}" ; sflag="true" ;;
		:) echo "Error: -${OPTARG} requires an argument." ; usage ;;
		*) usage ;;
	esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi
if [[ ! "${wflag}" ]]; then echo "-w option must be specified"; exit 1; fi
if [[ ! "${sflag}" ]]; then echo "-s option must be specified"; exit 1; fi
if [[ ! -d "${workdir}" ]]; then echo "directory ${workdir} does not exist."; exit 1; fi
if [[ ! "${fflag}" == "true" ]]; then archive="${ARCHIVE}"; fi


# enable and check tor
printf "STATUS: "
if [[ "${tflag}" == "true" ]]; then
	if ! . torsocks on; then
		echo "failed to enable torsocks"
		exit 1
	else
		printf "SENDING VIA NODE: "
		curl -s https://check.torproject.org/torbulkexitlist | grep "$(curl -s https://ident.me)" || { echo "current IP is not a TOR exist node"; exit 1; }
	fi
else
	echo "torsocks is not enabled"
	echo "SENDING VIA: $(curl -s https://ident.me)"
fi

# change workdir
echo "CHANGING WORKING DIR TO: ${workdir}"
cd "${workdir}" || { echo "cannot change workdir, aborting"; exit 1; }

# archive pdf directory
echo "CREATING ARCHIVE: ${archive}"
tar -C "${PDF_PATH}" -cf "${archive}" .

# send to web
case ${service} in
	transfer.sh|transfer)
		echo "SENDING TO TRANSFER.SH: ${archive}"
		time curl --progress-bar --upload-file "${archive}" "https://transfer.sh/$(basename  "${archive}")" -H "${TRANSFERSH_HEADER}" | tee /dev/null | grep "https" > "${CONFIG_PATH}/transfer_url"
	;;
	bashupload.com|bashupload)
		echo "SENDING TO BASHUPLOAD.COM: ${archive}"
		time curl --progress-bar --upload-file "${archive}" "https://bashupload.com/$(basename  "${archive}")" | tee /dev/null | grep -Eo "(http|https)://[a-zA-Z0-9./?=_%:-]*" > "${CONFIG_PATH}/transfer_url"
	;;
	0x0.st|0x0)
		echo "SENDING TO 0X0.ST: ${archive}"
		time curl --progress-bar -F"file=@${archive}" https://0x0.st | tee /dev/null > "${CONFIG_PATH}/transfer_url"
	;;
	oshi.at|oshi)
		echo "SENDING TO OSHI.AT: ${archive}"
		time curl --progress-bar --upload-file "${archive}" "https://oshi.at/$(basename  "${archive}")" | tee /dev/null | grep '\[Download\]' | grep -Eo "(http|https)://[a-zA-Z0-9./?=_%:-]*" > "${CONFIG_PATH}/transfer_url"
	;;
	anonfiles.com|anonfiles)
		echo "SENDING TO ANONFILES.COM: ${archive}"
		time curl -F "file=@${archive}" https://api.anonfiles.com/upload | jq -r '.data[].url.full' > "${CONFIG_PATH}/transfer_url"
	;;
	filechan.org|filechan)
		echo "SENDING TO FILECHAN.ORG: ${archive}"
		time curl -F "file=@${archive}" https://api.filechan.org/upload | jq -r '.data[].url.full' > "${CONFIG_PATH}/transfer_url"
	;;
	letsupload.cc|letsupload)
		echo "SENDING TO LETSUPLOAD.CC: ${archive}"
		time curl -F "file=@${archive}" https://api.letsupload.cc/upload | jq -r '.data[].url.full' > "${CONFIG_PATH}/transfer_url"
	;;
	*)
		echo "Unexpected option: ${service}"
		exit 1
	;;
esac

# delete old file
if [[ "${dflag}" == "true" ]]; then
	echo "DELETING OLD FILE: ${archive}"
	rm -f "${archive}"
fi

# get url
printf "PUBLIC URL: "
cat "${CONFIG_PATH}/transfer_url"

# write nginx configuration
if [[ "${nflag}" == "true" ]]; then
	echo "WRITING NGINX CONFIGURATION TO: ${nginx_config}"
	cat > "${nginx_config}" <<EOF
location = /archive.tar { return 301 $(cat "${CONFIG_PATH}/transfer_url"); }
EOF
	printf "CHECKING AND RESTARTING NGINX: "
	nginx_restart
fi
