#!/bin/bash

# print usage info
usage() {
        echo "Usage: ${BASH_SOURCE[0]} -c etc/config.mk"
	echo "   -n generate unlisted nginx"
	echo "   -r restart nginx"
        exit 1
} ; if [[ "$#" -lt 1 ]]; then usage; fi

# parse options
while getopts ":c:nr" opt; do
    case "${opt}" in
        c) . "${OPTARG}" && cflag=true ;;     # etc/config.mk
	n) nflag=true ;;
        r) rflag=true ;;
        :) echo "Error: -${OPTARG} requires an argument." ; usage ;;
        *) usage ;;
    esac
done

# check options
if [[ ! "${cflag}" ]]; then echo "-c option must be specified"; exit 1; fi

# generate unlisted nginx
if [[ "${nflag}" == "true" ]]; then
	echo "updating unlisted nginx data.."
	rm -f "${UNLISTED_NGX}"
	rm -f "${UNLISTED_NGX}.noif"

	while IFS= read -r url; do
		# write nginx configuration
		cat >> "${UNLISTED_NGX}" <<EOT
location = /libre/${url}.pdf { if (\$allowed_country = no) { rewrite ^ ${IPFS_PDF_DIR}/${url}.pdf redirect; } }
EOT

	cat >> "${UNLISTED_NGX}.noif" <<EOT
location = /libre/${url}.pdf { rewrite ^ ${IPFS_PDF_DIR}/${url}.pdf redirect; }
EOT
	done < <(sqlite3 "${AMUSEWIKI_DB}" "SELECT ${BOOK_SLUG_RULE} FROM books WHERE directory NOT LIKE '%unlisted%'" | url_slug)

	while IFS= read -r url; do
		# write nginx configuration
		cat >> "${UNLISTED_NGX}" <<EOT
location = /book/${url} { if (\$allowed_country = no) { rewrite ^ /book/${url}/ redirect; } }
location = /libre/${url}.pdf { if (\$allowed_country = no) { rewrite ^ /book/${url}/ redirect; } }
location /book/${url}/ { if (\$allowed_country = no) { return 451; error_page 451 /451/${url}/index.html; } }
EOT

                cat >> "${UNLISTED_NGX}.noif" <<EOT
location = /book/${url} { rewrite ^ /book/${url}/ redirect; }
location = /libre/${url}.pdf { rewrite ^ /book/${url}/ redirect; }
location /book/${url}/ { return 451; error_page 451 /451/${url}/index.html; }
EOT
	done < <(sqlite3 "${AMUSEWIKI_DB}" "SELECT ${BOOK_SLUG_RULE} FROM books WHERE directory LIKE '%unlisted%'" | url_slug)

fi

# restart nginx
if [[ "${rflag}" == "true" ]]; then
	nginx_restart
else
	echo "# restart nginx:"
	echo "nginx -t && systemctl restart nginx.service"
fi
