#!/bin/bash

# print usage info
usage() {
	echo "Usage: ${BASH_SOURCE[0]} -1 input_one -2 input_two -t string_type -n title_type -c config
  -t:
	file		input type is a file
	string		input type is a string
  -n:
        book		input is a book
        author		input is a author"
        exit 1
} ; if [[ "$#" -lt 10 ]]; then usage; fi

while getopts ":1:2:t:n:c:" opt; do
	case "${opt}" in
		1) input_one="${OPTARG}" ; flag1=true ;;
		2) input_two="${OPTARG}" ; flag2=true ;;
		t) STRING_TYPE="${OPTARG}" ; tflag=true ;;
		n) TITLE_TYPE="${OPTARG}" ; nflag=true ;;
		c) . "${OPTARG}" ; cflag=true ;;
		:) echo "Error: -${OPTARG} requires an argument." ; usage ;;
		*) usage ;;
	esac
done

if [[ ! "${flag1}" == "true" ]]; then echo "-1 flag must be specified"; ifexist=true; fi
if [[ ! "${flag2}" == "true" ]]; then echo "-2 flag must be specified"; ifexist=true; fi
if [[ ! "${tflag}" == "true" ]]; then echo "-t flag must be specified"; ifexist=true; fi
if [[ ! "${nflag}" == "true" ]]; then echo "-n flag must be specified"; ifexist=true; fi
if [[ ! "${cflag}" == "true" ]]; then echo "-c flag must be specified"; ifexist=true; fi
if [[ "${ifexit}" == "true" ]]; then exit 1; fi


case "${STRING_TYPE}" in
	file)
		count_one="$(wc -l 2>/dev/null < "${input_one}")"
		count_two="$(wc -l 2>/dev/null < "${input_two}")"
		if [[ ! "${count_one}" == "${count_two}" ]]; then echo "line count is not equal"; ifexist=true; fi
		if [[ ! -f "${input_one}" ]]; then echo "${input_one} is not a file"; ifexit=true; fi
		if [[ ! -f "${input_two}" ]]; then echo "${input_two} is not a file"; ifexit=true; fi
		if [[ "${ifexit}" == "true" ]]; then exit 1; fi

		readarray -t old_url < "${input_one}"
		readarray -t new_url < "${input_two}"

		echo "#$(date -R)" > "${GENERATOR_PATH}/var/extra/url_rule.conf"
		rm -f "${GENERATOR_PATH}/var/extra/rename_pdfs.sh"

		for i in $(seq 0 $((${#old_url[@]}-1))); do
			if [[ "${old_url[$i]}" == "${new_url[$i]}" ]]; then continue; fi
			case "${TITLE_TYPE}" in
				book)
					echo "location = /libre/${old_url[$i]}.pdf { return 301 /libre/${new_url[$i]}.pdf; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
					echo "location = /book/${old_url[$i]} { return 301 /book/${new_url[$i]}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
					echo "location = /book/${old_url[$i]}/ { return 301 /book/${new_url[$i]}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
					echo "location = /book/${old_url[$i]}/image.jpeg { return 301 /book/${new_url[$i]}/image.jpeg; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
					echo "mv \"${PDF_PATH}/${old_url[$i]}.pdf\" \"${PDF_PATH}/${new_url[$i]}.pdf\"" >> "${GENERATOR_PATH}/var/extra/rename_pdfs.sh"
				;;
				author)
					echo "location = /author/${old_url[$i]} { return 301 /author/${new_url[$i]}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
					echo "location = /author/${old_url[$i]}/ { return 301 /author/${new_url[$i]}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
				;;
				*)
					echo "Unknow title type: ${TITLE_TYPE}"
					usage
					exit 1
				;;
			esac
		done
		echo -e "check:\n"
                test -f "${GENERATOR_PATH}/var/extra/url_rule.conf"  && echo "${GENERATOR_PATH}/var/extra/url_rule.conf"
		test -f "${GENERATOR_PATH}/var/extra/rename_pdfs.sh" && echo "${GENERATOR_PATH}/var/extra/rename_pdfs.sh"
	;;
	string)
		if [[ "${input_one}" == "${input_two}" ]]; then exit 0; fi
		echo "#$(date -R)" > "${GENERATOR_PATH}/var/extra/url_rule.conf"
		rm -f "${GENERATOR_PATH}/var/extra/rename_pdfs.sh"
		case "${TITLE_TYPE}" in
			book)
				echo "location = /libre/${input_one}.pdf { return 301 /libre/${input_two}.pdf; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
				echo "location = /book/${input_one} { return 301 /book/${input_two}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
				echo "location = /book/${input_one}/ { return 301 /book/${input_two}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
				echo "location = /book/${input_one}/image.jpeg { return 301 /book/${input_two}/image.jpeg; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
				echo "mv \"${PDF_PATH}/${input_one}.pdf\" \"${PDF_PATH}/${input_two}.pdf\"" > "${GENERATOR_PATH}/var/extra/rename_pdfs.sh"
			;;
			author)
				echo "location = /author/${input_one} { return 301 /author/${input_two}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
				echo "location = /author/${input_one}/ { return 301 /author/${input_two}/; }" >> "${GENERATOR_PATH}/var/extra/url_rule.conf"
			;;
			*)
				echo "Unknow title type: ${TITLE_TYPE}"
				usage
				exit 1
		esac

                echo -e "check:\n"
                test -f "${GENERATOR_PATH}/var/extra/url_rule.conf"  && echo "${GENERATOR_PATH}/var/extra/url_rule.conf"
                test -f "${GENERATOR_PATH}/var/extra/rename_pdfs.sh" && echo "${GENERATOR_PATH}/var/extra/rename_pdfs.sh"
	;;
	*)
		echo "Unexpected option: ${STRING_TYPE}"
		usage
		exit 1
	;;
esac
